; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below.
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

[Command]
name = "MoeMoeKyun"
command = ~F, D, B, F, D, B, x+y
time = 40

[Command]
name = "GitasWhirlwind"
command = ~D, F, D, F, x
time = 20

[Command]
name = "GitasWhirlwind"   ;Same name as above
command = ~D, F, D, F, y
time = 20


;-| Special Motions |------------------------------------------------------
[Command]
name = "QCF_xy"
command = ~D, F, x+y

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCB_xy"
command = ~D, B, x+y

[Command]
name = "QCB_x"
command = ~D, B, x

[Command]
name = "QCB_y"
command = ~D, B, y

[Command]
name = "QCF_ab"
command = ~D, F, a+b

[Command]
name = "QCF_a"
command = ~D, F, a

[Command]
name = "QCF_b"
command = ~D, F, b

[Command]
name = "QCB_ab"
command = ~D, B, a+b

[Command]
name = "QCB_a"
command = ~D, B, a

[Command]
name = "QCB_b"
command = ~D, B, b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = z
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1
;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]
[State 0, AssertSpecial]
Type = AssertSpecial
Flag = NoWalk
Flag2 = NoStandGuard
Flag3 = NoCrouchGuard
Trigger1 = AILevel
IgnoreHitPause = 1
 
[State 0, AssertSpecial]
Type = AssertSpecial
Flag = NoAirGuard
Trigger1 = AILevel
IgnoreHitPause = 1

[state -1, Variable Reset]
Type = VarSet
IgnoreHitPause = 1
V = 59
Value = enemy,cond(numpartner&&(!Alive),partner,id,id)
trigger1 = numenemy

[state -1, Candy Check]
Type = VarSet
IgnoreHitPause = 1
V = 57
Value = (numhelper(1035)||numhelper(1036)||numhelper(1037)||numhelper(1038))
trigger1 = numenemy

[state -1, Reset Combo Check]
Type = VarSet
IgnoreHitPause = 1
V = 58
Value = 0
triggerall = numenemy
trigger1 = p2movetype != H
trigger2 = p2stateno = [5110,5120]

[state -1, Variable Reset]
Type = VarSet
IgnoreHitPause = 1
FV = (38)
Value = fvar(39)
trigger1 = fvar(39) != 0

[state -1, Variable Reset]
Type = VarSet
IgnoreHitPause = 1
FV = (39)
Value = 0
Triggerall = fvar(38) = fvar(39)    ;AI only
trigger1 = Time = 1
trigger2 = !AnimTime 
trigger3 = PlayerID(var(59)),time = 1
trigger4 = stateno = [6060,6069]

[state -1, Full AI Programming, Reversal]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	(AILevel) && !fvar(39)    ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	alive           ;Only when alive
trigger1	=	power>1000
Trigger1	=	P2BodyDist Y>=const(size.head.pos.y)-50   ;vertical distance (non-anti-air situations)
Trigger1	=	P2BodyDist X<=130  ;Horizontal distance (maximum range)
Trigger1	=	StateType != A	;Set for appropriate StateType
Trigger1	=	stateno = 152 || stateno = 154                   ;while having control
trigger1	=	1 + (fvar(39) := 6070)

[state -1, Full AI Programming, Combo Specific]
Type = Null
IgnoreHitPause = 1
triggerall	=	 !fvar(39)    ;AI only
TriggerAll	=	(ailevel) 
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	numenemy
triggerall	=	alive           ;Only when alive
trigger1	=	movehit = 1 || random<48*moveguarded
Trigger1	=	stateno=200                       ;combo condition
trigger2	=	movehit = 1 || random<48*moveguarded
Trigger2	=	stateno=230                       ;combo condition
Trigger3	=	random%4<3 || var(57) || p2statetype = C                      ;combo condition
trigger3	=	movehit = 1 || random<(32*moveguarded)
Trigger3	=	cond(stateno=240,animelemtime(10)>0,1)     ;combo condition
Trigger3	=	stateno=240||stateno=410                       ;combo condition
trigger4	=	!var(57)
trigger4	=	cond(p2statetype = C,moveguarded,1) 
trigger4	=	movehit = 1 || random<(64*moveguarded)
Trigger4	=	cond(stateno=240,random%4<4,1)                       ;combo condition
Trigger4	=	cond(stateno=240,animelemtime(10)>0,1)     ;combo condition
Trigger4	=	stateno=240||stateno=410 ||stateno = 216                      ;combo condition
trigger5	=	power>500
trigger5	=	hitcount>5
trigger5	=	animelemtime(7)>0
Trigger5	=	stateno=1111                       ;combo condition
Trigger6	=	movecontact = 1                       ;combo 
trigger6	=	stateno=630
Trigger7	=	movecontact = 1                       ;combo 
trigger7	=	stateno=600
Trigger8	=	movehit = 1                       ;combo 
trigger8	=	stateno=216
Trigger9	=	gametime%5<2                       ;combo condition
Trigger9	=	ctrl                       ;combo condition
trigger9	=	var(58) = 1
trigger1	=	1 + (fvar(39) := 410)
trigger2	=	1 + (fvar(39) := cond(p2statetype!=C&&p2bodydist x < 40&&random%4<2,410,240))
trigger3	=	1 + (fvar(39) := cond(random%4<2||moveguarded,215,1101))
trigger3	=	1 + (var(58) := cond(fvar(38)!=1101,2,0))
trigger4	=	1 + (fvar(39) := cond(stateno=216&&moveguarded,1030,1031))
trigger5	=	1 + (fvar(39) := 6060)
trigger5	=	1 + (var(58) := 1)
trigger6	=	1 + (fvar(39):=640)
trigger7	=	1 + (fvar(39):=610)
trigger8	=	1 + (fvar(39):=3000)
trigger9	=	1 + (fvar(39):=cond(random%4<=1,100,230))
trigger9	=	1 + (var(58) := 0)


[state -1, Full AI Programming, Standard]
Type = Null
IgnoreHitPause = 1
triggerall	=	!fvar(39)    ;AI only
triggerall	=	!InGuardDist 
TriggerAll	=	(AILevel) 
triggerall	=	roundstate=2
triggerall	=	numenemy   ;Only when fighting
triggerall	=	alive           ;Only when alive
trigger1	=	time>1
trigger1	=	playerid(var(59)),prevstateno != 5120
trigger1	=	p2stateno != 5120
trigger1	=	p2Movetype!=H
trigger1	=	p2statetype!=L
trigger1	=	p2statetype!=A
trigger1	=	 p2bodydist x<10 ;other conditions
trigger1	=	ctrl
trigger1	=	statetype!=A
trigger2	=	!enemynear, hitfall ;not in hitfall
trigger2	=	random < 200 || p2movetype=H && Time > 1 ;randomizer
trigger2	=	p2statetype!=L         ;standard state conditions
Trigger2	=	P2BodyDist Y>=const(size.head.pos.y)+50   ;vertical distance (non-anti-air situations)
Trigger2	=	P2BodyDist X=[-20,89]  ;Horizontal distance (maximum range)
Trigger2	=	Ctrl                   ;while having control
Trigger2	=	StateType != A	;Set for appropriate StateType
trigger3	=	enemy(numenemy>1),vel y >= -2 ;enemy jump-in conditions
Trigger3	=	P2BodyDist Y<=const(size.head.pos.y)+60   ;vertical distance (anti-air situations, aim for the general vicinity of the attack's hitbox)
trigger3	=	P2BodyDist X=[-20,50]
trigger4	=	p2statetype != A
trigger4	=	cond(prevstateno=100,time<5,p2BodyDist X <= 50)
trigger4	=	ctrl
trigger4	=	statetype = A
trigger5	=	p2statetype = A
trigger5	=	p2bodydist Y <= const(size.mid.pos.y)+20
trigger5	=	p2BodyDist X <= 50
trigger5	=	ctrl
trigger5	=	statetype = A
trigger6	=	random<200||var(57)
trigger6	=	p2statetype!= A
trigger6	=	p2statetype!= L
trigger6	=	p2BodyDist X/40.0 >=2
trigger6	=	ctrl
trigger6	=	statetype != A
trigger7	 = numhelper(1035)<1
trigger7	 = numhelper(1036)<1
trigger7	 = numhelper(1037)<1
trigger7	 = numhelper(1038)<1
trigger7	=	p2movetype=I
trigger7	=	ctrl
trigger7	=	StateType!=A
Trigger8	=	ctrl||!AnimTime                       ;combo condition
trigger8	=	var(58) = [2,3]
;-------------------------------------------------
trigger1	=	1 + (fvar(39) := 800)
trigger2	=	1 + (fvar(39) := cond(random%5<2,215,230))
trigger2	=	1 + (var(58) := cond(fvar(38)=215,2,0))
trigger3	=	1 + (fvar(39) := 200)
trigger4	=	1 + (fvar(39) := 630)
trigger5	=	1 + (fvar(39) := 600)
trigger6	=	1 + (fvar(39) := 100)
trigger7	=	1 + (fvar(39) := 1030+(frontedgebodydist > 2 * 70))
trigger8	=	1 + (fvar(39):=215)
trigger8	=	1 + (var(58) := cond(power>1000,3,0))
;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(1) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact
var(1) = 1


;---------------------------------------------------------------------------
;Moe Moe Kyun! (Hyper)
[State -1, Moe Moe Kyun! (Hyper)]
type = ChangeState
value = 3050
triggerall = command = "MoeMoeKyun"
triggerall = power >= 3000
triggerall = !AILevel
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Gita's Whirlwind (Hyper)
[State -1, Gita's Whirlwind (Hyper)]
type = ChangeState
value = 3000
triggerall = power >= 1000
triggerall = fvar(39) = 3000
triggerall = statetype !=A
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Sweet Rain (Air) (Light)
[State -1, Sweet Rain (Air) (Light)]
type = ChangeState
value = 1230
triggerall = numhelper(1035)<1
triggerall = numhelper(1036)<1
triggerall = numhelper(1037)<1
triggerall = numhelper(1038)<1
triggerall = fvar(39) = 1230
triggerall = statetype =A
trigger1 = ctrl
trigger2 = (stateno = [600,610]) || (stateno = [630,640]) && movecontact

;---------------------------------------------------------------------------
;Sweet Rain (Air) (Strong)
[State -1, Sweet Rain (Air) (Strong)]
type = ChangeState
value = 1240
triggerall = numhelper(1035)<1
triggerall = numhelper(1036)<1
triggerall = numhelper(1037)<1
triggerall = numhelper(1038)<1
triggerall = fvar(39) = 1231
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [600,610]) || (stateno = [630,640]) && movecontact

;---------------------------------------------------------------------------
;Ho-Kago Dive Time! (EX)
[State -1, Ho-Kago Dive Time! (EX)]
type = ChangeState
value = 1220
triggerall = power >= 500
triggerall = fvar(39) = 1202
triggerall = statetype =A
trigger1 = ctrl
trigger2 = (stateno = [600,610]) || (stateno = [630,640]) && movecontact

;---------------------------------------------------------------------------
;Ho-Kago Dive Time! (Light)
[State -1, Ho-Kago Dive Time! (Light)]
type = ChangeState
value = 1200
triggerall = fvar(39) = 1200
triggerall = statetype =A
trigger1 = ctrl
trigger2 = (stateno = [600,610]) || (stateno = [630,640]) && movecontact

;---------------------------------------------------------------------------
;Ho-Kago Dive Time! (Strong)
[State -1, Ho-Kago Dive Time! (Strong)]
type = ChangeState
value = 1210
triggerall = fvar(39) = 1201
triggerall = statetype =A
trigger1 = ctrl
trigger2 = (stateno = [600,610]) || (stateno = [630,640]) && movecontact

;---------------------------------------------------------------------------
;Sweet Rain (Light)
[State -1, Sweet Rain (Light)]
type = ChangeState
value = 1030
triggerall = numhelper(1035)<1
triggerall = numhelper(1036)<1
triggerall = numhelper(1037)<1
triggerall = numhelper(1038)<1
triggerall = fvar(39) = 1030
triggerall = statetype !=A
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Sweet Rain (Strong)
[State -1, Sweet Rain (Strong)]
type = ChangeState
value = 1040
triggerall = numhelper(1035)<1
triggerall = numhelper(1036)<1
triggerall = numhelper(1037)<1
triggerall = numhelper(1038)<1
triggerall = fvar(39) = 1031
triggerall = statetype !=A
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Heart Seal (Light)
[State -1, Heart Seal (Light)]
type = ChangeState
value = 1000
triggerall = numhelper(1001)<1
triggerall = numhelper(1011)<1
triggerall = fvar(39) = 1000
triggerall = statetype !=A
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Heart Seal (Strong)
[State -1, Heart Seal (Strong)]
type = ChangeState
value = 1010
triggerall = fvar(39) = 1001
triggerall = statetype !=A
triggerall = numhelper(1001)<1
triggerall = numhelper(1011)<1
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Sneak Assault (EX)
[State -1, Sneak Assault (EX)]
type = ChangeState
value = 1120
triggerall = power >= 500
triggerall = fvar(39) = 1102
triggerall = statetype !=A
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Sneak Assault (Light)
[State -1, Sneak Assault (Light)]
type = ChangeState
value = 1100
triggerall = fvar(39) = 1100
triggerall = statetype !=A
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Sneak Assault (Strong)
[State -1, Sneak Assault (Strong)]
type = ChangeState
value = 1110
triggerall = fvar(39) = 1101
triggerall = statetype !=A
trigger1 = var(1) ;Use combo condition (above)

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = fvar(39) = 100
trigger1 = statetype !=A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = fvar(39) = 105
trigger1 = statetype !=A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Throw
[State -1, Throw]
type = ChangeState
value = 800
triggerall = fvar(39) = 800
triggerall = statetype != A
triggerall = ctrl
triggerall = stateno != 100
trigger1 = p2bodydist X < 10
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H

;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = fvar(39) = 200
trigger1 = statetype !=A
trigger1 = ctrl
trigger2 = stateno = 200 
trigger2 = time > 12

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = fvar(39) = 210
trigger1 = statetype !=A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Standing Roll
[State -1, Standing Roll]
type = ChangeState
value = 215
triggerall = fvar(39) = 215
trigger1 = statetype !=A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = fvar(39) = 230
trigger1 = statetype !=A
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = time > 12

;---------------------------------------------------------------------------
;Standing Rump Shaker
[State -1, Standing Rump Shaker]
type = ChangeState
value = 240
triggerall = fvar(39) = 240
trigger1 = statetype !=A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
triggerall = !AILevel
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = fvar(39) = 400
trigger1 = statetype !=A
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = time > 15

;---------------------------------------------------------------------------
;Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = fvar(39) = 410
trigger1 = statetype !=A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = fvar(39) = 430
trigger1 = statetype !=A
trigger1 = ctrl
trigger2 = stateno = 430 
trigger2 = time > 15

;---------------------------------------------------------------------------
;Crouching Senton
[State -1, Crouching Senton]
type = ChangeState
value = 440
triggerall = fvar(39) = 440
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = fvar(39) = 600
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = time > 12

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = fvar(39) = 610
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 630) && movecontact

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = fvar(39) = 630
trigger1 = statetype = A
trigger1 = ctrl 
trigger2 = stateno = 630
trigger2 = time > 30

;---------------------------------------------------------------------------
;Jump Drop Kick
[State -1, Jump Drop Kick]
type = ChangeState
value = 640
triggerall = fvar(39) = 640
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 630) && movecontact

;---------------------------------------------------------------------------
; Dizzy Cancel (Stand)
[State -1, |Dizzy Cancel Stand|]
type = ChangeState
value = 6060+(statetype = S)
triggerall =  movetype != H
triggerall = statetype != C
triggerall = var(3) < 3
triggerall = fvar(39) = 6060
trigger1 = (stateno = [600,699]) || (stateno = [1130,1141]) || (stateno = [1201,1211])
trigger1 = movehit
trigger2 = (stateno = [200,499]) || (stateno = [1100,1111])
trigger2 = movehit
trigger3 = (stateno = [1030,1041])
trigger3 = movehit
;---------------------------------------------------------------------------
; Dizzy Cancel (Crouch)
[State -1, |Dizzy Cancel Crouch|]
type = ChangeState
value = 6062
triggerall =  movetype != H
triggerall = statetype = C
triggerall = var(3) < 3
triggerall = fvar(39) = 6060
trigger1 = (stateno = [600,699]) || (stateno = [1130,1141]) || (stateno = [1201,1211])
trigger1 = movehit
trigger2 = (stateno = [200,499]) || (stateno = [1100,1111])
trigger2 = movehit
trigger3 = (stateno = [1030,1041])
trigger3 = movehit

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Air)
[State -1, |Dizzy Guard Cancel Air|]
type = ChangeState
value = 6070
triggerall =  movetype = H
triggerall = statetype = A
triggerall = fvar(39) = 6070
trigger1 = stateno = 154

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Stand)
[State -1, |Dizzy Guard Cancel Stand|]
type = ChangeState
value = 6071
triggerall =  movetype = H
triggerall = statetype = S
triggerall = fvar(39) = 6070
trigger1 = stateno = 150

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Crouch)
[State -1, |Dizzy Guard Cancel Crouch|]
type = ChangeState
value = 6072
triggerall =  movetype = H
triggerall = statetype = C
triggerall = fvar(39) = 6070
trigger1 = stateno = 152

; Guard State
[State -1, |120]
type = ChangeState
value = 120
triggerall = ctrl
triggerall = AILevel
TriggerAll = RoundState = 2
TriggerAll = NumEnemy
TriggerAll = Alive
trigger1 = InGuardDist
trigger2 = p2movetype = A
trigger2 = p2stateno >= 3000
; Jump Blocking State
[State -1, |120]
type = ChangeState
value = 0
ctrl = 1
triggerall = stateno = 40
triggerall = AILevel
TriggerAll = RoundState = 2
TriggerAll = NumEnemy
TriggerAll = Alive
trigger1 = P2MoveType = H


;---------------------------------------------------------------------------

;---------------------------------------------------------------------------
;Moe Moe Kyun! (Hyper)
[State -1, Moe Moe Kyun! (Hyper)]
type = ChangeState
value = 2050
triggerall = command = "MoeMoeKyun"
triggerall = power >= 3000
triggerall = !AILevel
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Gita's Whirlwind (Hyper)
[State -1, Gita's Whirlwind (Hyper)]
type = ChangeState
value = 3000
triggerall = command = "GitasWhirlwind"
triggerall = power >= 1000
triggerall = !AILevel
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Sweet Rain (Air) (Light)
[State -1, Sweet Rain (Air) (Light)]
type = ChangeState
value = 1230
triggerall = command = "QCB_x"
triggerall = numhelper(1035)<1
triggerall = numhelper(1036)<1
triggerall = numhelper(1037)<1
triggerall = numhelper(1038)<1
triggerall = !AILevel
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [600,610]) || (stateno = [630,640]) && movecontact

;---------------------------------------------------------------------------
;Sweet Rain (Air) (Strong)
[State -1, Sweet Rain (Air) (Strong)]
type = ChangeState
value = 1240
triggerall = command = "QCB_y"
triggerall = numhelper(1035)<1
triggerall = numhelper(1036)<1
triggerall = numhelper(1037)<1
triggerall = numhelper(1038)<1
triggerall = !AILevel
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [600,610]) || (stateno = [630,640]) && movecontact

;---------------------------------------------------------------------------
;Ho-Kago Dive Time! (EX)
[State -1, Ho-Kago Dive Time! (EX)]
type = ChangeState
value = 1220
triggerall = command = "QCF_xy"
triggerall = power >= 500
triggerall = !AILevel
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [600,610]) || (stateno = [630,640]) && movecontact

;---------------------------------------------------------------------------
;Ho-Kago Dive Time! (Light)
[State -1, Ho-Kago Dive Time! (Light)]
type = ChangeState
value = 1200
triggerall = command = "QCF_x"
triggerall = !AILevel
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [600,610]) || (stateno = [630,640]) && movecontact

;---------------------------------------------------------------------------
;Ho-Kago Dive Time! (Strong)
[State -1, Ho-Kago Dive Time! (Strong)]
type = ChangeState
value = 1210
triggerall = command = "QCF_y"
triggerall = !AILevel
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [600,610]) || (stateno = [630,640]) && movecontact

;---------------------------------------------------------------------------
;Sweet Rain (Light)
[State -1, Sweet Rain (Light)]
type = ChangeState
value = 1030
triggerall = command = "QCB_x"
triggerall = numhelper(1035)<1
triggerall = numhelper(1036)<1
triggerall = numhelper(1037)<1
triggerall = numhelper(1038)<1
triggerall = !AILevel
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Sweet Rain (Strong)
[State -1, Sweet Rain (Strong)]
type = ChangeState
value = 1040
triggerall = command = "QCB_y"
triggerall = numhelper(1035)<1
triggerall = numhelper(1036)<1
triggerall = numhelper(1037)<1
triggerall = numhelper(1038)<1
triggerall = !AILevel
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Heart Seal (Light)
[State -1, Heart Seal (Light)]
type = ChangeState
value = 1000
triggerall = command = "QCF_x"
triggerall = numhelper(1001)<1
triggerall = numhelper(1011)<1
triggerall = !AILevel
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Heart Seal (Strong)
[State -1, Heart Seal (Strong)]
type = ChangeState
value = 1010
triggerall = command = "QCF_y"
triggerall = numhelper(1001)<1
triggerall = numhelper(1011)<1
triggerall = !AILevel
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Sneak Assault (EX)
[State -1, Sneak Assault (EX)]
type = ChangeState
value = 1120
triggerall = command = "QCF_ab"
triggerall = power >= 500
triggerall = !AILevel
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Sneak Assault (Light)
[State -1, Sneak Assault (Light)]
type = ChangeState
value = 1100
triggerall = command = "QCF_a"
triggerall = !AILevel
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Sneak Assault (Strong)
[State -1, Sneak Assault (Strong)]
type = ChangeState
value = 1110
triggerall = command = "QCF_b"
triggerall = !AILevel
trigger1 = var(1) ;Use combo condition (above)

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = !AILevel

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = !AILevel

;---------------------------------------------------------------------------
;Throw
[State -1, Throw]
type = ChangeState
value = 800
triggerall = command = "y"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
triggerall = !AILevel
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 6
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 10
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = !AILevel
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 
trigger2 = time > 12

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = !AILevel
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Standing Roll
[State -1, Standing Roll]
type = ChangeState
value = 215
triggerall = command = "holdfwd" && command = "holddown" && command = "y"
triggerall = statetype != A
triggerall = !AILevel
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = !AILevel
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = time > 12

;---------------------------------------------------------------------------
;Standing Rump Shaker
[State -1, Standing Rump Shaker]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = !AILevel
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
triggerall = !AILevel
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
triggerall = !AILevel
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = time > 15

;---------------------------------------------------------------------------
;Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
triggerall = !AILevel
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
triggerall = !AILevel
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 430 
trigger2 = time > 15

;---------------------------------------------------------------------------
;Crouching Senton
[State -1, Crouching Senton]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
triggerall = !AILevel
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
triggerall = !AILevel
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = time > 12

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = command = "y"
triggerall = !AILevel
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 630) && movecontact

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
triggerall = !AILevel
trigger1 = statetype = A
trigger1 = ctrl 
trigger2 = stateno = 630
trigger2 = time > 30

;---------------------------------------------------------------------------
;Jump Drop Kick
[State -1, Jump Drop Kick]
type = ChangeState
value = 640
triggerall = command = "b"
triggerall = !AILevel
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 630) && movecontact

;---------------------------------------------------------------------------
; Dizzy Cancel (Stand)
[State -1, |Dizzy Cancel Stand|]
type = ChangeState
value = 6060+(statetype = S)
triggerall =  movetype != H
triggerall = statetype != C
triggerall = var(3) < 3
triggerall = command = "c" && power > 500
triggerall = !AILevel
trigger1 = (stateno = [600,699]) || (stateno = [1130,1141]) || (stateno = [1201,1211])
trigger1 = movehit
trigger2 = (stateno = [200,499]) || (stateno = [1100,1111])
trigger2 = movehit
trigger3 = (stateno = [1030,1041])
trigger3 = movehit
;---------------------------------------------------------------------------
; Dizzy Cancel (Crouch)
[State -1, |Dizzy Cancel Crouch|]
type = ChangeState
value = 6062
triggerall =  movetype != H
triggerall = statetype = C
triggerall = var(3) < 3
triggerall = command = "c" && power > 500
triggerall = !AILevel
trigger1 = (stateno = [600,699]) || (stateno = [1130,1141]) || (stateno = [1201,1211])
trigger1 = movehit
trigger2 = (stateno = [200,499]) || (stateno = [1100,1111])
trigger2 = movehit
trigger3 = (stateno = [1030,1041])
trigger3 = movehit

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Air)
[State -1, |Dizzy Guard Cancel Air|]
type = ChangeState
value = 6070
triggerall =  movetype = H
triggerall = statetype = A
triggerall = command = "z" && power > 1000
triggerall = !AILevel
trigger1 = stateno = 154

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Stand)
[State -1, |Dizzy Guard Cancel Stand|]
type = ChangeState
value = 6071
triggerall =  movetype = H
triggerall = statetype = S
triggerall = command = "z" && power > 1000
triggerall = !AILevel
trigger1 = stateno = 150

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Crouch)
[State -1, |Dizzy Guard Cancel Crouch|]
type = ChangeState
value = 6072
triggerall =  movetype = H
triggerall = statetype = C
triggerall = command = "z" && power > 1000
triggerall = !AILevel
trigger1 = stateno = 152

;---------------------------------------------------------------------------

;---------------------------------------------------------------------------
; GUARD (start)
[Statedef 120]
type = U    ;Leave state type unchanged
physics = U ;Leave physics unchanged

[State 120, 1]
type = ChangeAnim
trigger1 = Time = 0
value = 120 + (statetype = C) + (statetype = A)*2

[State 120, 2]
type = StateTypeSet
trigger1 = Time = 0 && statetype = S
physics = S

[State 120, 3]
type = StateTypeSet
trigger1 = Time = 0 && statetype = C
physics = C

[State 120, 4]
type = StateTypeSet
trigger1 = Time = 0 && statetype = A
physics = A

[State 120, Hi to Lo]
type = StateTypeSet
trigger1=p2statetype=C
trigger1=statetype=S
trigger1=ailevel>=1
statetype = C
physics = C

[State 120, Lo to Hi]
type = StateTypeSet
trigger1=p2statetype!=C
trigger1=statetype=C
trigger1=ailevel>=1
statetype = S
physics = S 
 
[State 120, Hi to Lo]
type = StateTypeSet
triggerall = !AILevel
trigger1 = statetype = S && command = "holddown"
statetype = C
physics = C

[State 120, Lo to Hi]
type = StateTypeSet
triggerall = !AILevel
trigger1 = statetype = C && command != "holddown"
statetype = S
physics = S

[State 120, 5]
type = ChangeState
trigger1 = AnimTime = 0
value = 130 + (statetype = C) + (statetype = A)*2

[State 120, Stop Guarding]
type = ChangeState
trigger1 = !AILevel
trigger1 = command != "holdback"
trigger2 = !inguarddist
value = 140

;---------------------------------------------------------------------------
; Stand guard (guarding)
[Statedef 130]
type    = S
physics = S

[State 130, 1]
type = ChangeAnim
trigger1 = Anim != 130
value = 130

[State 130, Hi to Lo]
type = ChangeState
trigger1 = P2StateType=C
trigger1 = AILevel
value = 131

[State 130, Hi to Lo]
type = ChangeState
trigger1 = command = "holddown"
trigger1 = !AILevel
value = 131

[State 130, Stop Guarding]
type = ChangeState
trigger1 = command != "holdback"
trigger1 = !AILevel
trigger2 = !inguarddist
value = 140

;---------------------------------------------------------------------------
; Crouch guard (guarding)
[Statedef 131]
type    = C
physics = C

[State 131, 1]
type = ChangeAnim
trigger1 = Anim != 131
value = 131

[State 131, Lo to Hi]
type = ChangeState
trigger1 = P2StateType!=C
Trigger1 = Time >= 30
trigger1 = AILevel
value = 130
[State 131, Lo to Hi]
type = ChangeState
trigger1 = command != "holddown"
trigger1 = !AILevel
value = 130

[State 131, Stop Guarding]
type = ChangeState
trigger1 = command != "holdback"
trigger1 = !AILevel
trigger2 = !inguarddist
value = 140

;---------------------------------------------------------------------------
; Air guard (guarding)
[Statedef 132]
type    = A
physics = N

[State 132, 1]
type = ChangeAnim
trigger1 = Anim != 132
value = 132

[State 132, 2]
type = VelAdd
trigger1 = 1
y = Const(movement.yaccel)

[State 132, 3]
type = VarSet
trigger1 = 1
sysvar(0) = (pos y >= 0) && (vel y > 0)

[State 132, 4]
type = VelSet
trigger1 = sysvar(0)
y = 0

[State 132, 5]
type = PosSet
trigger1 = sysvar(0)
y = 0

[State 132, 6]
type = ChangeState
triggerall = sysvar(0)
triggerall = inguarddist
trigger1 = command = "holdback"
trigger1 = !AILevel
trigger2 = AILevel
value = 130

[State 132, 7]
type = ChangeState
trigger1 = sysvar(0)
value = 52

[State 132, Stop Guarding]
type = ChangeState
trigger1 = !AILevel
trigger1 = command != "holdback"
trigger2 = !inguarddist
value = 140

;---------------------------------------------------------------------------
; Guard (end)
[Statedef 140]
type = U    ;Leave state type unchanged
physics = U ;Leave physics unchanged
ctrl = 1

[State 140, 1]
type = ChangeAnim
trigger1 = Time = 0
value = 140 + (statetype = C) + (statetype = A)*2

[State 120, 2]
type = StateTypeSet
trigger1 = Time = 0 && statetype = S
physics = S

[State 120, 3]
type = StateTypeSet
trigger1 = Time = 0 && statetype = C
physics = C

[State 120, 4]
type = StateTypeSet
trigger1 = Time = 0 && statetype = A
physics = A

[State 120, Hi to Lo]
type = StateTypeSet
trigger1=p2statetype=C
trigger1=statetype=S
trigger1=ailevel>=1
statetype = C
physics = C

[State 120, Lo to Hi]
type = StateTypeSet
trigger1=p2statetype!=C
trigger1=statetype=C
trigger1=ailevel>=1
statetype = S
physics = S 
 
[State 120, Hi to Lo]
type = StateTypeSet
triggerall = !AILevel
trigger1 = statetype = S && command = "holddown"
statetype = C
physics = C

[State 120, Lo to Hi]
type = StateTypeSet
triggerall = !AILevel
trigger1 = statetype = C && command != "holddown"
statetype = S
physics = S

;[State 140, 5] ;Implemented within engine
;type = ChangeState
;trigger1 = AnimTime = 0
;value = (statetype = C)*11 + (statetype = A)*51

;---------------------------------------------------------------------------
; Stand guard hit (shaking)
[Statedef 150]
type    = S
movetype= H
physics = N
velset = 0,0

[State 150, 1]
type = ChangeAnim
trigger1 = 1
value = 150

[State 150, 2]
type = ChangeState
trigger1 = AILevel
trigger1 = HitShakeOver
value = 151 + 2*(StateType=C)

[State 150, 2]
type = ChangeState
trigger1 = !AILevel
trigger1 = HitShakeOver
value = 151 + 2*(command = "holddown")

[State 120, Hi to Lo]
type = StateTypeSet
trigger1=p2statetype=C
trigger1=statetype=S
trigger1=ailevel>=1
statetype = C
physics = C

[State 120, Lo to Hi]
type = StateTypeSet
trigger1=p2statetype!=C
trigger1=statetype=C
trigger1=ailevel>=1
statetype = S
physics = S 
 
[State 120, Hi to Lo]
type = StateTypeSet
triggerall = !AILevel
trigger1 = statetype = S && command = "holddown"
statetype = C
physics = C

[State 120, Lo to Hi]
type = StateTypeSet
triggerall = !AILevel
trigger1 = statetype = C && command != "holddown"
statetype = S
physics = S

[State 150, 3]
type = ForceFeedback
trigger1 = time = 0
waveform = square
time = 3

;---------------------------------------------------------------------------
; Stand guard hit (knocked back)
[Statedef 151]
type    = S
movetype= H
physics = S
anim = 150

[State 151, 1]
type = HitVelSet
trigger1 = Time = 0
x = 1

[State 151, 2]
type = VelSet
trigger1 = Time = GetHitVar(slidetime)
trigger2 = HitOver
x = 0

[State 151, 3]
type = CtrlSet
trigger1 = Time = GetHitVar(ctrltime)
value = 1

[State 120, Hi to Lo]
type = StateTypeSet
trigger1=p2statetype=C
trigger1=statetype=S
trigger1=ailevel>=1
statetype = C
physics = C

[State 120, Lo to Hi]
type = StateTypeSet
trigger1=p2statetype!=C
trigger1=statetype=C
trigger1=ailevel>=1
statetype = S
physics = S 
 
[State 120, Hi to Lo]
type = StateTypeSet
triggerall = !AILevel
trigger1 = statetype = S && command = "holddown"
statetype = C
physics = C

[State 120, Lo to Hi]
type = StateTypeSet
triggerall = !AILevel
trigger1 = statetype = C && command != "holddown"
statetype = S
physics = S

[State 151, 4]
type = ChangeState
trigger1 = HitOver
value = 130
ctrl = 1

;---------------------------------------------------------------------------
; Crouch guard hit (shaking)
[Statedef 152]
type    = C
movetype= H
physics = N
velset = 0,0

[State 152, 1]
type = ChangeAnim
trigger1 = 1
value = 151

[State 150, 2]
type = ChangeState
trigger1 = AILevel
trigger1 = HitShakeOver
value = 151 + 2*(StateType=C)

[State 150, 2]
type = ChangeState
trigger1 = !AILevel
trigger1 = HitShakeOver
value = 151 + 2*(command = "holddown")

[State 120, Hi to Lo]
type = StateTypeSet
trigger1=p2statetype=C
trigger1=statetype=S
trigger1=ailevel>=1
statetype = C
physics = C

[State 120, Lo to Hi]
type = StateTypeSet
trigger1=p2statetype!=C
trigger1=statetype=C
trigger1=ailevel>=1
statetype = S
physics = S 
 
[State 120, Hi to Lo]
type = StateTypeSet
triggerall = !AILevel
trigger1 = statetype = S && command = "holddown"
statetype = C
physics = C

[State 120, Lo to Hi]
type = StateTypeSet
triggerall = !AILevel
trigger1 = statetype = C && command != "holddown"
statetype = S
physics = S

[State 152, 4]
type = ForceFeedback
trigger1 = time = 0
waveform = square
time = 4

;---------------------------------------------------------------------------
; Crouch guard hit (knocked back)
[Statedef 153]
type    = C
movetype= H
physics = C
anim = 151

[State 153, 1]
type = HitVelSet
trigger1 = Time = 0
x = 1

[State 153, 2]
type = VelSet
trigger1 = Time = GetHitVar(slidetime)
trigger2 = HitOver
x = 0

[State 153, 3]
type = CtrlSet
trigger1 = Time = GetHitVar(ctrltime)
value = 1

[State 120, Hi to Lo]
type = StateTypeSet
trigger1=p2statetype=C
trigger1=statetype=S
trigger1=ailevel>=1
statetype = C
physics = C

[State 120, Lo to Hi]
type = StateTypeSet
trigger1=p2statetype!=C
trigger1=statetype=C
trigger1=ailevel>=1
statetype = S
physics = S 
 
[State 120, Hi to Lo]
type = StateTypeSet
triggerall = !AILevel
trigger1 = statetype = S && command = "holddown"
statetype = C
physics = C

[State 120, Lo to Hi]
type = StateTypeSet
triggerall = !AILevel
trigger1 = statetype = C && command != "holddown"
statetype = S
physics = S

[State 153, 4]
type = ChangeState
trigger1 = HitOver
value = 131
ctrl = 1

;---------------------------------------------------------------------------
; Air guard hit (shaking)
[Statedef 154]
type    = A
movetype= H
physics = N
velset = 0,0

[State 154, 1]
type = ChangeAnim
trigger1 = 1
value = 152

[State 154, 2]
type = ChangeState
trigger1 = HitShakeOver
value = 155 ;AGUARDHIT2

[State 154, 3]
type = ForceFeedback
trigger1 = time = 0
waveform = square
time = 4

;---------------------------------------------------------------------------
; Air guard hit (knocked away)
[Statedef 155]
type    = A
movetype= H
physics = N
anim = 152

[State 155, 1]
type = HitVelSet
trigger1 = Time = 0
x = 1
y = 1

[State 155, 2]
type = VelAdd
trigger1 = 1
y = Const(movement.yaccel)

[State 155, 3]
type = CtrlSet
trigger1 = Time = GetHitVar(ctrltime)
value = 1

[State 155, 4]
type = VarSet
trigger1 = 1
sysvar(0) = (pos y >= 0) && (vel y > 0)

[State 155, 5]
type = VelSet
trigger1 = sysvar(0)
y = 0

[State 155, 6]
type = PosSet
trigger1 = sysvar(0)
y = 0

[State 155, 6]
type = ChangeState
triggerall = sysvar(0)
triggerall = inguarddist
trigger1 = !AILevel
trigger1 = command = "holdback"
trigger2 = AILevel
value = 130

[State 155, 7]
type = ChangeState
trigger1 = sysvar(0)
value = 52